#
# spec file for package yast2-python-bindings
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without python3
%if 0%{?sle_version} <= 150300
%bcond_without python2
%else
%bcond_with python2
%endif
Name:           yast2-python-bindings
Version:        5.0.2
Release:        1.2
Summary:        Python bindings for the YaST platform
License:        GPL-2.0-only
Group:          System/YaST
Source0:        %{name}-%{version}.tar.bz2
BuildRequires:  autoconf
BuildRequires:  autoconf-archive
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  libyui-devel
BuildRequires:  make
%if %{with python2}
BuildRequires:  python
%endif
BuildRequires:  python-rpm-macros
BuildRequires:  swig
BuildRequires:  yast2-core-devel
BuildRequires:  yast2-ycp-ui-bindings
BuildRequires:  yast2-ycp-ui-bindings-devel
%if %{with python2}
Requires:       python
%endif
Requires:       yast2-core
Requires:       yast2-ycp-ui-bindings
Conflicts:      yast2-python3-bindings
Obsoletes:      yast2-python-bindings < 4.0.1
%if %{with python2}
BuildRequires:  python-devel
%endif
%if %{with python3}
BuildRequires:  python3-devel
%endif

%description -n yast2-python-bindings
The bindings allow YaST modules to be written using the Python language
and also Python scripts can use YaST agents, APIs and modules.

%package -n yast2-python3-bindings
Summary:        Python3 bindings for the YaST platform
Group:          System/YaST
BuildRequires:  python3
Requires:       python3
Requires:       yast2-core
Requires:       yast2-ycp-ui-bindings
Conflicts:      yast2-python-bindings
Obsoletes:      yast2-python-bindings = 4.0.1

%description -n yast2-python3-bindings
The bindings allow YaST modules to be written using the Python language
and also Python scripts can use YaST agents, APIs and modules.

%prep
%setup -q

%build
make %{?_smp_mflags} -f Makefile.cvs all
%if %{with python3}
mkdir py3 && pushd py3
ln -s ../configure configure
%configure --enable-python3
%make_build
popd
%endif
%if %{with python2}
mkdir py2 && pushd py2
ln -s ../configure configure
%configure
%make_build
popd
%endif

%install
%if %{with_python3}
%make_install -C py3
%endif
%if %{with python2}
%make_install -C py2
%endif

%if %{with python3}
%files -n yast2-python3-bindings
%doc %{yast_docdir}
%{python3_sitelib}/*
%{python3_sitearch}/_ycp.so
%{yast_plugindir}/libpy2lang_python3.so.*
%{yast_plugindir}/libpy2lang_python3.so
%exclude %{yast_plugindir}/libpy2lang_python3.la
%endif

%if %{with python2}
%files -n yast2-python-bindings
%doc %{yast_docdir}
%{python_sitelib}/*
%{python_sitearch}/_ycp.so
%{yast_plugindir}/libpy2lang_python.so.*
%{yast_plugindir}/libpy2lang_python.so
%license COPYING
%exclude %{yast_plugindir}/libpy2lang_python.la
%endif

%changelog
* Mon Nov 13 2023 Noel Power <nopower@suse.com>
- Fix leak when passing Term objects; (bsc#1217075)
- 5.0.2
* Tue Sep 12 2023 Samuel Cabrero <scabrero@suse.de>
- Fix inspect.getargspec() removed in python3.11; (bsc#1215226);
- 5.0.1
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.cz>
- 5.0.0 (bsc#1185510)
* Fri Mar  3 2023 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.6.0 (bsc#1208913)
* Wed Feb  8 2023 Noel Power <nopower@suse.com>
- Misc fixes to examples; (bsc#1199343).
- Fix python2 utf8 handling (python2 code wasn't displaying unicode
  strings); (bsc#1199348).
- Change conversion of Py_None to YCP_Void instead of YCP_Null;
  (bsc#1199344).
- 4.5.2
* Wed Jun 22 2022 Noel Power <nopower@suse.com>
- Fix core with python3.10 when calling yast2 samba-client;
  (boo#1200804).
- 4.5.1
* Wed Apr  6 2022 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.5.0 (bsc#1198109)
* Thu Oct  7 2021 David Mulder <dmulder@suse.com>
- Fix yast2-python-bindings requires Python (bsc#1190890).
- 4.4.2
* Tue Aug 17 2021 Petr Pavlu <petr.pavlu@suse.com>
- Fix backtrace formatting for Python exceptions (bsc#1181595).
- 4.4.1
* Tue Apr 20 2021 Ladislav Slezák <lslezak@suse.cz>
- 4.4.0 (bsc#1185510)
* Tue Mar 30 2021 Noel Power <nopower@suse.com>
- Fix PyErrorHandler() function, normalise exception object;
  (bsc#1184182).
- 4.1.4
* Thu Mar 12 2020 Noel Power <nopower@suse.com>
- Fix build for python 3.8; (bsc#1166517)/
- 4.1.3
* Mon Feb 10 2020 dmulder@suse.com
- Don't overwrite CPPFLAGS/LDFLAGS/LIBADD during build; (bsc#1163310);
- 4.1.2
* Thu Jan  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to python3 on new releases of openSUSE as we no longer
  support python2 at all
- Cleanup the spec file to adhere to current packaging guidelines
* Tue May 21 2019 dmulder@suse.com
- yast2-python-bindings compilation errors when compiling with
  - Werror=format-security; (bsc#1133596);
- 4.1.1
* Tue Feb 26 2019 José Iván López González <jlopez@suse.com>
- Version bump (bsc#1124009)
- 4.1.0
* Wed Feb 20 2019 nopower@suse.com
- Fix python3 bindings error showning 'unexpect exception' and no
  trace information for errors; (bsc# 1126112).
- 4.0.9
* Fri Jan 18 2019 dmulder@suse.com
- Update to 4.0.8
  + Forward port python import capability, with improvements and
    code cleanup; (bsc#1122532).
  + Add pydocs to yast python
  + Improve building/packaging of python2/3
* Wed Jan  9 2019 dmulder@suse.com
- Define yast._() as an alias to gettext(); (bsc#1121106).
* Tue Jan  8 2019 dmulder@suse.com
- Provide textdomain() and gettext() functions for
  internationization; (bsc#1121106).
* Tue Oct 16 2018 schubi@suse.de
- Added license file to spec.
* Sat Sep 15 2018 nopower@suse.com
- Fix Id construction for python2, use items instead of iteritems
  for python2/python3 compatability; (bsc#1108558).
* Mon Aug 20 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Tue May 29 2018 dmulder@suse.com
- Don't package files in '/' (bsc#1095054).
* Fri Mar  9 2018 dmulder@suse.com
- Adapt the bindings to allow modules that will run in both python2
  or python3. Also fix a py3 binary mistakenly packaged with the py2
  bindings package (bsc#1074696).
* Mon Jan 29 2018 dmulder@suse.com
- Build both python2 and python3 versions of the bindings;
  (bsc#1074696).
* Thu Jan  4 2018 dmulder@suse.com
- Convert the bindings into python3; (bsc#1074696).
- Fix some code examples; (bsc#1070212).
* Tue Nov 28 2017 dmulder@suse.com
- Add example code ported from ruby examples; (bsc#1070212).
- Fixes based on findings from example code
* Wed Nov  8 2017 dmulder@suse.com
- Rewrite the python bindings using swig fate#324146
* Wed Nov 13 2013 jreidinger@suse.com
- Add explicit COPYING file
* Thu Sep 19 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Tue Jul 30 2013 yast-devel@opensuse.org
- version 3.0.0
* Tue Jun 11 2013 jmatejek@suse.com
- install to correct python directory (fixes file conflict with
  python-base)
- 2.20.2
* Fri Jun 29 2012 aschnell@suse.de
- blocxx is no longer needed for build
* Tue Jun 26 2012 aschnell@suse.de
- adapted to namespace changes in yast2-core
- 2.20.1
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Sep  6 2010 juhliarik@suse.cz
- added patch for building with python 2.7
- 2.20.0
* Thu Feb  4 2010 juhliarik@suse.cz
- added patch from (bnc#520499) it solves problem with importing
  names
- 2.19.0
* Mon Dec 15 2008 juhliarik@suse.cz
- added fix for problem with strict-aliasing (bnc #444472)
  - 2.17.4
* Wed Sep 24 2008 visnov@suse.cz
- y2debug is always logged (bnc#426554)
- 2.17.3
* Tue Sep  9 2008 visnov@suse.cz
- build with python 2.6
- 2.17.2
* Fri Jun 27 2008 juhliarik@suse.cz
- added support for GET/SET variables in YCP module (bnc #402684)
- 2.17.1
* Mon Feb 25 2008 juhliarik@suse.cz
- Added support for creating known widget names in ycp module
- V 2.16.6
* Thu Feb 21 2008 sh@suse.de
- Added new UI packages to Requires/BuildRequires in .spec file
- V 2.16.5
* Wed Feb 20 2008 sh@suse.de
- New include path for YUIComponent.h
- V 2.16.4
* Mon Jan 21 2008 juhliarik@suse.cz
- Added pacth for bug#355064 - problem with SCR.Write
- V 2.16.3
* Wed Dec  5 2007 juhliarik@suse.cz
- Added patch for problem with handling error from python
- Correction for handling adding None(nil) as argument to yast function
- V 2.16.2
* Thu Nov 15 2007 juhliarik@suse.cz
- Addded correction in makefile and for YCPDeclaration
- V 2.16.1
* Wed Nov 14 2007 juhliarik@suse.cz
- Adding solution for calling python function via reference
- Adding support for calling YCode in Sequencer from python
- Reimplementation SCR
- V 2.16.0
* Sun Sep  9 2007 juhliarik@suse.cz
- Adding support for calling SCR
- Adding support for ycp types symbol, term, path
- Adding support for calling UI from YaST
- Added patch for bug #308213 and bug# 300909
- V 2.15.3
* Fri Aug 10 2007 mvidner@suse.cz
- Finished integrating Feature #120292, UI as a namespace callable
  from yast2-*-bindings.
- 2.15.2
* Mon Aug  6 2007 juhliarik@suse.cz
- initial version
  V 2.15.1
